==> haskell-prettyprinter-ansi-terminal-1.1.1.2-50-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-FM73Bxpk1kXJM0w5ag7YCv
key: prettyprinter-ansi-terminal-1.1.1.2-FM73Bxpk1kXJM0w5ag7YCv
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: d90f51c560d50b066d98e2b0743d3d11
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-FM73Bxpk1kXJM0w5ag7YCv
depends:
    ansi-terminal-0.9.1-DB3Zf3I0Zem5oqZIKoyRWZ base-4.12.0.0
    prettyprinter-1.3.0-DFtPOWQpUL1DRfMvM9ilsI text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-prettyprinter-ansi-terminal-1.1.1.2-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-prettyprinter-ansi-terminal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: prettyprinter-ansi-terminal
version: 1.1.1.2
id: prettyprinter-ansi-terminal-1.1.1.2-5LSwmdw2wCmCNqH0yYOsGZ
key: prettyprinter-ansi-terminal-1.1.1.2-5LSwmdw2wCmCNqH0yYOsGZ
license: BSD-2-Clause
maintainer: David Luposchainsky <dluposchainsky at google>
author: David Luposchainsky
homepage: http://github.com/quchen/prettyprinter
synopsis: ANSI terminal backend for the »prettyprinter« package.
description:
    See README.md
category: User Interfaces, Text
abi: e05cc872dde981dd1ae5c236c2c0e958
exposed: True
exposed-modules:
    Data.Text.Prettyprint.Doc.Render.Terminal
    Data.Text.Prettyprint.Doc.Render.Terminal.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-ansi-terminal-1.1.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/prettyprinter-ansi-terminal-1.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/prettyprinter-ansi-terminal-1.1.1.2
hs-libraries: HSprettyprinter-ansi-terminal-1.1.1.2-5LSwmdw2wCmCNqH0yYOsGZ
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj base-4.12.0.0
    prettyprinter-1.3.0-JxGpgY9N8UHJNDVFKVjYkj text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html/prettyprinter-ansi-terminal.haddock
haddock-html: /usr/share/doc/haskell-prettyprinter-ansi-terminal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
